scikit_build_core: Build backend for CMake based projects
=========================================================

Description
-----------

Build backend for CMake based projects

License
-------

Upstream Contact
----------------

https://pypi.org/project/scikit-build-core/

